@@ -1,22 +1,25 @@
 #![doc = include_str!("readme.md")]
-mod as_element;
-mod elements;
-mod link;
-mod list;
-mod literal;
-mod quote;
-mod table;
+pub(crate) mod as_element;
+pub(crate) mod elements;
+pub(crate) mod link;
+pub(crate) mod list;
+pub(crate) mod literal;
+pub(crate) mod quote;
+pub(crate) mod table;
 
 pub use self::{
-    elements::*,
-    link::{EmailLink, HyperLink, HyperLinkTarget, ImageLayout, ImageLink, ResourceDescriptor, SmartLink, TagReference, TwoWayLink},
+    elements::{code_block::*, delimiter::*, header::*, math::*, styled::*, text::*},
+    link::*,
     list::*,
-    literal::Literal,
-    quote::QuoteBlock,
+    literal::*,
+    quote::*,
     table::*,
 };
-pub use crate::traits::Slugify;
-use crate::{command::CommandArguments, traits::IntoASTNode, Command, Value};
+use crate::{
+    command::CommandArguments,
+    traits::{IntoASTNode, Slugify},
+    Command, Value,
+};
 use notedown_error::{MaybeRanged, NoteError, Result};
 use num::{Signed, Zero};
 use std::{
@@ -47,43 +50,30 @@ pub type ASTNodes = Vec<Literal<ASTKind>>;
 pub enum ASTKind {
     /// Top Scope
     Statements(ASTNodes),
-    /// 
     /// - block only
     Paragraph(ASTNodes),
-    /// 
     /// - block only
     Delimiter(Box<Delimiter>),
-    /// 
     /// - block only
     Header(Box<Header>),
-    /// 
     /// - block only
     TableView(TableView),
-    /// 
     /// - block only
     ListView(ListView),
-    /// 
     /// - block only
     QuoteNode(Box<QuoteBlock>),
-    /// 
     /// - block + inline
     CodeNode(Box<CodeNode>),
-    /// 
     /// - block + inline
     MathNode(Box<MathNode>),
-    /// 
     /// - block + inline
     LinkNode(SmartLink),
-    /// 
     /// - inline only
     TextSpan(Box<TextSpan>),
-    /// 
     /// - inline only
     StyledSpan(Box<StyleNode>),
-    /// 
     /// - context sensitive
     Command(Box<Command>),
-    /// 
     /// - never bared
     Value(Box<Value>),
 }
