@@ -1,10 +1,21 @@
+mod literal_pattern;
 mod ordered_map;
+mod ordered_set;
 mod sparse_array;
 
+pub use literal_pattern::*;
 pub use ordered_map::*;
+pub use ordered_set::*;
+pub use sparse_array::*;
 
 use super::*;
 
+/// Ordered set of values
+#[derive(Clone, Default, Debug, Eq, PartialEq)]
+pub struct OrderedSet {
+    inner: IndexSet<Literal<Value>>,
+}
+
 /// Ordered map of key value pairs
 #[derive(Clone, Default, Debug, Eq, PartialEq)]
 pub struct OrderedMap {
@@ -18,6 +29,12 @@ pub struct LiteralPair {
     value: Literal<Value>,
 }
 
+/// Literal Patterns for command
+#[derive(Clone, Default, Eq, PartialEq)]
+pub struct LiteralPattern {
+    inner: Vec<Literal<String>>,
+}
+
 /// Sparse representation of the array, the subscript can be any non-zero integer
 /// 1-index
 #[derive(Clone, Default, Debug, Eq, PartialEq, Hash)]
